@@ -32,6 +32,7 @@ is_model <- function(x) {
       "averaging",
       "bamlss",
       "bamlss.frame",
+      "bayesGAM",
       "bayesmeta",
       "bayesx",
       "bayesQR",
@@ -79,6 +80,7 @@ is_model <- function(x) {
       "crch",
       "crq",
       "crqs",
+      "dglm",
       "DirichletRegModel",
       "drc",
       "emmGrid",
@@ -193,6 +195,7 @@ is_model <- function(x) {
       "nlreg",
       "nlrq",
       "nls",
+      "nparLD",
       "objectiveML",
       "ols",
       "orcutt",
