@@ -100,6 +100,7 @@ supported_models <- function() {
     "glimML",
     "glmm",
     "glm",
+    "Glm",
     "glmmadmb",
     "glmmPQL",
     "glmmTMB",
@@ -134,6 +135,7 @@ supported_models <- function() {
     "maxLik",
     "mcmc",
     "MCMCglmm",
+    "mediate",
     "metaplus",
     "merMod",
     "merModList",
@@ -146,6 +148,10 @@ supported_models <- function() {
     "mle2",
     "mlm",
     "mclogit",
+    "mcmc.list",
+    "meta_bma",
+    "meta_fixed",
+    "meta_random",
     "mlogit",
     "mmlogit",
     "multinom",
@@ -158,6 +164,7 @@ supported_models <- function() {
     "polr",
     "psm",
     "probitmfx",
+    "ridgelm",
     "rlm",
     "rlmerMod",
     "RM",
@@ -166,6 +173,7 @@ supported_models <- function() {
     "robmixglm",
     "rq",
     "rqss",
+    "scam",
     "sem",
     "speedlm",
     "speedglm",
