@@ -37,7 +37,7 @@ if (require("testthat") &&
   })
 
   test_that("get_random", {
-    expect_null(expect_warning(get_random(m1)))
+    expect_warning(expect_null(get_random(m1)))
   })
 
   test_that("find_response", {
@@ -84,7 +84,8 @@ if (require("testthat") &&
       list(
         conditional = as.formula("Euros ~ log(dist_km)"),
         cluster = as.formula("~Origin + Destination + Product")
-      )
+      ),
+      ignore_attr = TRUE
     )
     expect_length(find_formula(m2), 2)
     expect_equal(
@@ -92,7 +93,8 @@ if (require("testthat") &&
       list(
         conditional = as.formula("log1p(Euros) ~ log(dist_km)"),
         cluster = as.formula("~Origin + Destination + Product")
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
@@ -182,23 +184,9 @@ if (require("testthat") &&
   })
 
   test_that("get_statistic", {
-    expect_equal(
-      get_statistic(m1),
-      structure(list(
-        Parameter = "log(dist_km)", Statistic = -13.2102796112222
-      ),
-      class = "data.frame", row.names = c(NA, -1L), statistic = "z-statistic"
-      ),
-      tolerance = 1e-4
-    )
-    expect_equal(
-      get_statistic(m2),
-      structure(list(
-        Parameter = "log(dist_km)", Statistic = -14.0627647683725
-      ),
-      class = "data.frame", row.names = c(NA, -1L), statistic = "z-statistic"
-      ),
-      tolerance = 1e-4
-    )
+    stat <- get_statistic(m1)
+    expect_equal(stat$Statistic, -13.212695, tolerance = 1e-3)
+    stat <- get_statistic(m2)
+    expect_equal(stat$Statistic, -14.065336, tolerance = 1e-3)
   })
 }
