@@ -1,8 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("gee")) {
-  context("insight, model_info")
-
   data(warpbreaks)
   m1 <- gee(breaks ~ tension, id = wool, data = warpbreaks)
 
@@ -59,7 +57,8 @@ if (require("testthat") &&
       list(
         conditional = as.formula("breaks ~ tension"),
         random = as.formula("~wool")
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
