@@ -2,18 +2,17 @@
 
 if (.runThisTest && Sys.getenv("USER") != "travis") {
   if (require("testthat") && require("insight") && require("aod")) {
-    context("insight, negbin")
-
     data(dja)
     m1 <-
-      aod::negbin(y ~ group + offset(log(trisk)),
+      suppressWarnings(aod::negbin(y ~ group + offset(log(trisk)),
         random = ~village,
         data = dja
-      )
+      ))
 
     test_that("model_info", {
       expect_true(model_info(m1)$is_negbin)
       expect_true(model_info(m1)$is_mixed)
+      expect_false(model_info(m1)$is_linear)
     })
 
     test_that("find_predictors", {
@@ -73,7 +72,8 @@ if (.runThisTest && Sys.getenv("USER") != "travis") {
         list(
           conditional = as.formula("y ~ group + offset(log(trisk))"),
           random = as.formula("~village")
-        )
+        ),
+        ignore_attr = TRUE
       )
     })
 
@@ -126,7 +126,7 @@ if (.runThisTest && Sys.getenv("USER") != "travis") {
       )
       expect_equal(nrow(get_parameters(m1)), 2)
       expect_equal(
-        get_parameters(m1)$parameter,
+        get_parameters(m1)$Parameter,
         c("(Intercept)", "groupTREAT")
       )
     })
